#
# spec file for package netty-tcnative
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global namedreltag .Final
%global namedversion %{version}%{?namedreltag}
%if 0%{?suse_version} < 1500 || 0%{?gcc_version} < 11
%define with_gcc 11
%endif
Name:           netty-tcnative
Version:        2.0.72
Release:        1.1
Summary:        Fork of Tomcat Native with improved OpenSSL and mavenized build
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://github.com/netty/netty/wiki/Forked-Tomcat-Native
Source0:        https://github.com/netty/netty-tcnative/archive/%{name}-parent-%{namedversion}.tar.gz
Source1:        fixLibNames.patch.in
Source2:        https://repo1.maven.org/maven2/io/netty/netty-jni-util/0.0.9.Final/netty-jni-util-0.0.9.Final-sources.jar
Source100:      %{name}-rpmlintrc
BuildRequires:  apr-devel
BuildRequires:  fdupes
BuildRequires:  gcc%{?with_gcc}-c++
BuildRequires:  java-devel >= 1.8
BuildRequires:  libopenssl-devel
BuildRequires:  maven-local
BuildRequires:  unzip
BuildRequires:  mvn(ant-contrib:ant-contrib)
BuildRequires:  mvn(kr.motd.maven:os-maven-plugin)
BuildRequires:  mvn(org.apache.ant:ant)
BuildRequires:  mvn(org.apache.ant:ant-commons-net)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.fusesource.hawtjni:hawtjni-maven-plugin)
BuildRequires:  mvn(org.sonatype.oss:oss-parent:pom:)

%description
netty-tcnative is a fork of Tomcat Native. It includes a set of changes
contributed by Twitter, Inc, such as:
 *  Simplified distribution and linkage of native library
 *  Complete mavenization of the project
 *  Improved OpenSSL support
To minimize the maintenance burden, we create a dedicated branch for each stable
upstream release and apply our own changes on top of it, while keeping the
number of maintained branches to minimum

%package openssl-dynamic
Summary:        Netty/TomcatNative [OpenSSL - Dynamic]]
Group:          Development/Libraries/Java

%description openssl-dynamic
A Mavenized fork of Tomcat Native which incorporates various patches.

This artifact is dynamically linked to OpenSSL and Apache APR.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description javadoc
%{summary}.

%prep
%setup -q -n %{name}-%{name}-parent-%{namedversion}

for i in openssl-classes openssl-dynamic; do
  mkdir -p ${i}/target/netty-jni-util
  unzip %{SOURCE2} -d ${i}/target/netty-jni-util
done

# Will be regenerated by hawtjni-maven-plugin
rm -rf openssl-dynamic/src/main/native-package/configure.*

sed "s;@PATH@;%{_libdir};g" < %{SOURCE1} | patch -p1

# Build only the openssl-dynamic module
%pom_disable_module openssl-static
%pom_disable_module boringssl-static
%pom_disable_module libressl-static

%pom_remove_plugin :module-info
%pom_remove_plugin :japicmp-maven-plugin
%pom_remove_plugin :maven-enforcer-plugin
%pom_remove_plugin -r :maven-javadoc-plugin

%pom_remove_dep io.netty:netty-jni-util
%pom_remove_plugin :maven-dependency-plugin

%pom_remove_plugin :maven-scm-plugin boringssl-static

%pom_remove_plugin :maven-source-plugin openssl-classes

# Tell xmvn to install attached artifact, which it does not
# do by default. In this case install all attached artifacts with
# the linux classifier.
%{mvn_package} ":{*}-parent" __noinstall
%{mvn_package} ":::sources:" __noinstall
%{mvn_package} ":::javadoc:" __noinstall
%{mvn_package} ":{*}-classes"
%{mvn_package} ":{*}::linux*:" @1
%{mvn_package} ":{*}" @1

%{mvn_alias} :netty-tcnative :netty-tcnative-openssl-static :netty-tcnative-boringssl-static :netty-tcnative-libressl-static

%build
%if 0%{?with_gcc}
export CXX=g++-%{with_gcc}
export CC=gcc-%{with_gcc}
%endif
%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

install -dm 0755 %{buildroot}%{_libdir}
install -pm 0755 openssl-dynamic/target/native-build/target/lib/libnetty_tcnative.so %{buildroot}%{_libdir}/

%files -f .mfiles

%files openssl-dynamic -f .mfiles-%{name}
%{_libdir}/libnetty_tcnative.so

%files javadoc -f .mfiles-javadoc

%changelog
* Mon Jun  9 2025 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.0.72 Final
  * No formal changelog present
* Tue Feb 11 2025 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.0.70 Final
  * No formal changelog present
* Wed Dec  4 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.0.69 Final
  * No formal changelog present
* Tue Nov 26 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.0.68 Final
  * No formal changelog present
- Build also the dynamic openssl provider and alias it to the
  static openssl, libressl and boringssl ones.
* Wed Oct 30 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.0.67 Final
  * No formal changelog present
    (https://github.com/netty/netty-tcnative/issues/860)
* Wed Mar 27 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.0.65 Final
  * No formal changelog present. Required by netty 4.1.108
* Thu Oct 12 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.0.62 Final
  * No formal changelog present. This artifact and netty are
    closely bound
  * Upgrade the netty-jni-util sources jar to version 0.0.9.Final
* Wed Sep 13 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Fri Jun 23 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.0.61 Final
  * Implements the SSLContext.setMaxCertList method needed by
    netty 4.1.94 which contains important security updates
  * No formal changelog present. This artifact and netty are
    closely bound
* Thu Mar 30 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.0.59 Final
  * new artifact name netty-tcnative-classes, provided by this
    version is required by netty 4.1.90 which contains important
    security updates
  * No formal changelog present. This artifact is closely bound
    to the netty releases
* Mon Apr 25 2022 Fridrich Strba <fstrba@suse.com>
- Remove dependency on separate package netty-jni-util-sources
- Unpack the sources to their right place without passing through
  maven mechanisms
- This version fixes bsc#1198792
* Wed Mar 23 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 1.8
* Wed Mar 24 2021 Fridrich Strba <fstrba@suse.com>
- Update to the 2.0.36 Final
  * Includes many changes, from which the relevalt ones are:
    + Upgrade to OpenSSL 1.1.1i
    + Update to latest openssl version for static build
    + Update to LibreSSL 3.1.4
    + Update to latest stable libressl release
    + Update to openssl 1.1.1g
    + OpenSSL 1.1.1d
    + Update to libressl 2.9.3
    + Upgrade to openssl 1.1.1c
    + Update OpenSSL to 1.1.1b and LibreSSL to 2.8.3
    + Cleanup BoringSSL TLSv1.3 support and consistent handle empty ciphers.
    + Support TLSv1.3 with compiling against boringssl
    + Return 0 for SSL_OP_NO_TLSv1_3 when TLSv1.3 is not supported.
    + Add support for TLSv1.3 when compiled against openssl 1.1.1
    + Allow to load a private key from the OpenSSL engine.
    + Support KeyManagerFactory if compiled against OpenSSL < 1.0.2 but using OpenSSL >= 1.0.2 at runtime.
    + Update to libressl 2.6.4
    + Update to openssl 1.0.2n
    + Update to libressl 2.5.5
    + Allow to compile with openssl 1.0.1
    + Update deprecated methods and OpenSSL api changes to allow building with OpenSSL 1.1.0e
    + Update to libressl 2.4.5
    + Update openssl to 1.0.2k
    + Ensure we can compile against openssl 1.1.x and libressl 2.5.x as well.
    + Update libressl to 2.4.2
    + Update openssl to 1.0.2j
    + Update openssl to 1.0.2i
  * fix build in factory
* Thu Jan  9 2020 Fridrich Strba <fstrba@suse.com>
- Update to the 1.1.33 Final26, the last version of 1.1 series
- Use directement libtcnative-1-0 package, since it is API
  compatible and supports openssl 1.1.x
- Removed patch:
  * i388aprFix.patch
    + Integrated upstream
* Thu Nov 14 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of netty-tcnative 1.1.30
